@@ -212,7 +212,7 @@ def latex_visit_blockdiag(self, node):
 
 
 def on_doctree_resolved(self, doctree, docname):
-    if self.builder.name in ('html', 'latex'):
+    if self.builder.name in ('gettext', 'singlehtml', 'html', 'latex'):
         return
 
     for node in doctree.traverse(blockdiag):  
@@ -227,7 +227,8 @@ def on_doctree_resolved(self, doctree, docname):
             image.draw()
             image.save()
 
-        image = nodes.image(uri=outfn)
+        candidates = {'image/png': outfn}
+        image = nodes.image(uri=outfn, candidates=candidates)
         node.parent.replace(node, image)
 
 
